Struct Canceled

struct Canceled

Error returned from a Receiver when the corresponding Sender is dropped.

Implementations

impl Clone for Canceled

fn clone(self: &Self) -> Canceled

impl Copy for Canceled

impl Debug for Canceled

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Display for Canceled

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Eq for Canceled

impl Error for Canceled

impl Freeze for Canceled

impl PartialEq for Canceled

fn eq(self: &Self, other: &Canceled) -> bool

impl RefUnwindSafe for Canceled

impl Send for Canceled

impl StructuralPartialEq for Canceled

impl Sync for Canceled

impl Unpin for Canceled

impl UnsafeUnpin for Canceled

impl UnwindSafe for Canceled

impl<T> Any for Canceled

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Canceled

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Canceled

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Canceled

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Canceled

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Canceled

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> ToString for Canceled

fn to_string(self: &Self) -> String

impl<T, U> Into for Canceled

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Canceled

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Canceled

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>