Struct Cancellation
struct Cancellation<'a, T> { ... }
A future that resolves when the receiving end of a channel has hung up.
This is an .await-friendly interface around poll_canceled.
Implementations
impl<'a, T> Freeze for Cancellation<'a, T>
impl<'a, T> RefUnwindSafe for Cancellation<'a, T>
impl<'a, T> Send for Cancellation<'a, T>
impl<'a, T> Sync for Cancellation<'a, T>
impl<'a, T> Unpin for Cancellation<'a, T>
impl<'a, T> UnsafeUnpin for Cancellation<'a, T>
impl<'a, T> UnwindSafe for Cancellation<'a, T>
impl<'a, T: $crate::fmt::Debug> Debug for Cancellation<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<F> IntoFuture for Cancellation<'a, T>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<T> Any for Cancellation<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Cancellation<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Cancellation<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Cancellation<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Future for Cancellation<'_, T>
fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<()>
impl<T, U> Into for Cancellation<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Cancellation<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Cancellation<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>